==> kmymoney2-trinity_3.5.13.2.orig.tar.xz: kmymoney-trinity-3.5.13.2/kmymoney2/dialogs/kmergetransactionsdlg.h <==
/***************************************************************************
                          kmergetransactionsdlg.h
                             -------------------
    begin                : Sun Aug 20 2006
    copyright            : (C) 2006 by Ace Jones
    email                : <acejones@users.sf.net>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMERGETRANSACTIONSDLG_H
#define KMERGETRANSACTIONSDLG_H

// ----------------------------------------------------------------------------
// QT Includes

class TQResizeEvent;

// ----------------------------------------------------------------------------
// KDE Includes

#include <kdebug.h>

// ----------------------------------------------------------------------------
// Project Includes

#include <kmymoney/register.h>
#include <kmymoney/mymoneyaccount.h>

#include "../dialogs/kselecttransactionsdlg.h"

class KMergeTransactionsDlg: public KSelectTransactionsDlg
{
  Q_OBJECT
  TQ_OBJECT
public:
  KMergeTransactionsDlg(const MyMoneyAccount& account, TQWidget* parent = 0, const char* name = 0);

  bool eventFilter(TQObject* , TQEvent* ) { return false; }

public slots:
  void slotHelp();
};

#endif // KMERGETRANSACTIONSDLG_H
// vim:cin:si:ai:et:ts=2:sw=2:

==> kmymoney2-trinity_14.0.8.orig.tar.xz: kmymoney-trinity-14.0.8/kmymoney2/dialogs/kmergetransactionsdlg.h <==
/***************************************************************************
                          kmergetransactionsdlg.h
                             -------------------
    begin                : Sun Aug 20 2006
    copyright            : (C) 2006 by Ace Jones
    email                : <acejones@users.sf.net>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMERGETRANSACTIONSDLG_H
#define KMERGETRANSACTIONSDLG_H

// ----------------------------------------------------------------------------
// QT Includes

class TQResizeEvent;

// ----------------------------------------------------------------------------
// KDE Includes

#include <kdebug.h>

// ----------------------------------------------------------------------------
// Project Includes

#include <kmymoney/register.h>
#include <kmymoney/mymoneyaccount.h>

#include "../dialogs/tdeselecttransactionsdlg.h"

class KMergeTransactionsDlg: public TDESelectTransactionsDlg
{
  Q_OBJECT
  
public:
  KMergeTransactionsDlg(const MyMoneyAccount& account, TQWidget* parent = 0, const char* name = 0);

  bool eventFilter(TQObject* , TQEvent* ) { return false; }

public slots:
  void slotHelp();
};

#endif // KMERGETRANSACTIONSDLG_H
// vim:cin:si:ai:et:ts=2:sw=2:
